@@ -9,6 +9,7 @@ ICLUST.cluster <- function (r.mat,ICLUST.options) {#should allow for raw data, c
 #          
 #initialize  various arrays and get ready for the first pass
 output <- ICLUST.options$output
+
 num.var <- nrow(r.mat)
 keep.clustering <- TRUE          #used to determine when we are finished clustering
 results <- data.frame(matrix(rep(0,18*(num.var-1)),ncol=18))
@@ -31,7 +32,7 @@ count=1
 while (keep.clustering) {   #loop until we figure out we should stop
 #find similiarities
  #we will do most of the work on a copy of the r.mat
-cluster.stats <- cluster.cor(clusters,r.mat,FALSE,digits=9)  
+cluster.stats <- cluster.cor(clusters,r.mat,FALSE,digits=9,SMC=ICLUST.options$SMC)  
 sim.mat <- cluster.stats$cor    #the correlation matrix
 diag(sim.mat) <- 0   #we don't want 1's on the diagonal to mess up the maximum 
 
@@ -176,7 +177,7 @@ if((size1 < 2) && (size2  < 2)) {
 #first, does alpha increase?
 test.alpha <- TRUE
 
-if (ICLUST.options$alpha>0) { #should we apply any tests?
+if (ICLUST.options$alpha>0) { #should we apply the alpha test?
 if (ICLUST.options$alpha.size < min(size1,size2)) {
   switch(ICLUST.options$alpha, {if (alpha < min(alpha1,alpha2)) {if (output>2) {print(
   paste ('do not combine ', cluster.names[max.row],"with", cluster.names[max.col],
@@ -195,7 +196,7 @@ if (ICLUST.options$alpha.size < min(size1,size2)) {
 
 #second, does beta increase ?
 test.beta <- TRUE          
-if (ICLUST.options$beta>0) { #should we apply any tests?
+if (ICLUST.options$beta>0) { #should we apply the beta test?
 if (ICLUST.options$beta.size < min(size1,size2)) {
   switch(ICLUST.options$beta, {if (beta.combined < min(beta1,beta2)) {if (output>2) {print(
   paste ('do not combine ', cluster.names[max.row],"with", cluster.names[max.col],'new beta =',
@@ -218,8 +219,8 @@ if (ICLUST.options$beta.size < min(size1,size2)) {
 
 
 if(test.beta & test.alpha) { break} else { #we have failed the combining criteria 
-         
-            if((ICLUST.options$n.clus > 0) & ((num.var - count -1 ) < ICLUST.options$n.clus) ) {warning ("Clusters formed as requested do not meet the alpha and beta criteria. Perhaps you should rethink the number of cluster settings.")
+
+            if((ICLUST.options$n.clus > 0) & ((num.var - count -1 ) <= ICLUST.options$n.clus) ) {warning ("Clusters formed as requested do not meet the alpha and beta criteria. Perhaps you should rethink the number of cluster settings.")
 			                break } else {   
 			if (beta.combined < ICLUST.options$beta.min) {
 			
