@@ -33,7 +33,10 @@ if(nvar < 12) e.size <- e.size * .7   #this is a kludge to make small problems l
 
 if(is.null(min.size)) min.size <- .1 * nvar
 plot(0,type="n",xlim=limx,ylim=limy,frame.plot=FALSE,axes=FALSE,ylab="",xlab="",main=main)
-
+new.max.len <- max(strwidth(var.labels))
+if (new.max.len > max.len) {limx <- c(-new.max.len
+,nvar+2)
+plot(0,type="n",xlim=limx,ylim=limy,frame.plot=FALSE,axes=FALSE,ylab="",xlab="",main=main)}
 top <- num.var
 done <- 0
 if (nc==1) {head <- num
